@@ -2,7 +2,7 @@ import configparser
 import argparse
 from pickle import HIGHEST_PROTOCOL
 from fitsnap3.io.sections.section_factory import new_section
-from fitsnap3.parallel_tools import pt
+from fitsnap3.parallel_tools import pt, output
 from os import path, listdir
 
 
@@ -14,7 +14,7 @@ class Config:
         self.parse_cmdline()
         self.sections = {}
         self.parse_config()
-        self._reset_alloyflag()
+        self._reset_chemflag()
 
     def parse_cmdline(self):
         parser = argparse.ArgumentParser(prog="FitSNAP3")
@@ -54,16 +54,17 @@ class Config:
         parser.add_argument("--pscreen", "-ps", action="store_true", dest="pscreen",
                             help="Print each processors screen")
         parser.add_argument("--log", action="store", dest="log",
-                            default="log.fitsnap", help="Write fitsnap log to this file")
+                            default=None, help="Write fitsnap log to this file")
 
         self.args = parser.parse_args()
 
     def parse_config(self):
 
         tmp_config = configparser.ConfigParser(inline_comment_prefixes='#')
+        tmp_config.optionxform = str
         tmp_config.read(self.args.infile)
 
-        vprint = pt.single_print if self.args.verbose else lambda *arguments, **kwargs: None
+        vprint = output.screen if self.args.verbose else lambda *arguments, **kwargs: None
         if self.args.keyword_replacements:
             for kwg, kwn, kwv in self.args.keyword_replacements:
                 if kwg not in tmp_config:
@@ -86,13 +87,13 @@ class Config:
                 self.sections[section] = new_section(section, tmp_config, self.args)
         del temp
 
-    def _reset_alloyflag(self):
-        if self.sections["CALCULATOR"].alloyflag != 0:
-            alloyflag = "{}".format(self.sections['BISPECTRUM'].numtypes)
+    def _reset_chemflag(self):
+        if self.sections["CALCULATOR"].chemflag != 0:
+            chemflag = "{}".format(self.sections['BISPECTRUM'].numtypes)
             for element in self.sections["BISPECTRUM"].type_mapping:
                 element_type = self.sections["BISPECTRUM"].type_mapping[element]
-                alloyflag += " {}".format(element_type - 1)
-            self.sections["CALCULATOR"].alloyflag = "{}".format(alloyflag)
+                chemflag += " {}".format(element_type - 1)
+            self.sections["CALCULATOR"].chemflag = "{}".format(chemflag)
 
 
 if __name__ == "fitsnap3.io.input":
