@@ -30,8 +30,6 @@
 # <!-----------------END-HEADER------------------------------------->
 
 from fitsnap3.io.input import config
-from pandas import read_csv
-from tqdm import tqdm
 from os import path, listdir, stat
 import numpy as np
 from random import shuffle
@@ -40,6 +38,14 @@ from fitsnap3.io.output import output
 # from natsort import natsorted
 
 
+def _float_to_int(a_float):
+    if a_float == 0:
+        return int(a_float)
+    if a_float/int(a_float) != 1:
+        raise ValueError("Training and Testing Size must be interpretable as integers")
+    return int(a_float)
+
+
 class Scraper:
 
     def __init__(self, name):
@@ -47,6 +53,7 @@ class Scraper:
         self.group_types = {}
         self.group_table = []
         self.files = {}
+        self.configs = {}
         self.tests = None
         self.convert = {"Energy": 1.0, "Force": 1.0, "Stress": 1.0, "Distance": 1.0}
         self.data = {}
@@ -54,47 +61,62 @@ class Scraper:
         self._init_units()
 
     def scrape_groups(self):
-        self.group_types = {'name': str, 'size': float, 'eweight': float, 'fweight': float, 'vweight': float}
-        group_names = [key for key in self.group_types]
+        group_dict = {k: config.sections["GROUPS"].group_types[i]
+                      for i, k in enumerate(config.sections["GROUPS"].group_sections)}
+        self.group_table = config.sections["GROUPS"].group_table
+        size_type = None
+        testing_size_type = None
 
-        self.group_table = read_csv(config.sections["PATH"].group_file,
-                                    delim_whitespace=True,
-                                    comment='#',
-                                    skip_blank_lines=True,
-                                    names=group_names,
-                                    index_col=False)
+        for key in self.group_table:
+            bc_bool = False
+            training_size = None
+            if 'size' in self.group_table[key]:
+                training_size = self.group_table[key]['size']
+                bc_bool = True
+                size_type = group_dict['size']
+            if 'training_size' in self.group_table[key]:
+                if training_size is not None:
+                    raise ValueError("Do not set both size and training size")
+                training_size = self.group_table[key]['training_size']
+                size_type = group_dict['training_size']
+            if 'testing_size' in self.group_table[key]:
+                testing_size = self.group_table[key]['testing_size']
+                testing_size_type = group_dict['testing_size']
+            else:
+                testing_size = 0
+            if training_size is None:
+                raise ValueError("Please set training size for {}".format(key))
 
-        # Remove blank lines ; skip_blank_lines doesn't seem to work.
-        self.group_table = self.group_table.dropna()
-        self.group_table.index = range(len(self.group_table.index))
-
-        # Convert data types
-        self.group_table = self.group_table.astype(dtype=dict(self.group_types))
-
-        for group_info in tqdm(self.group_table.itertuples(),
-                               desc="Groups",
-                               position=0,
-                               total=len(self.group_table),
-                               disable=(not config.args.verbose),
-                               ascii=True):
-            group_name = group_info.name
-            folder = path.join(config.sections["PATH"].datapath, group_name)
+            folder = path.join(config.sections["PATH"].datapath, key)
             folder_files = listdir(folder)
             for file_name in folder_files:
                 if folder not in self.files:
                     self.files[folder] = []
                 self.files[folder].append([folder + '/' + file_name, int(stat(folder + '/' + file_name).st_size)])
             shuffle(self.files[folder], pt.get_seed)
-            if group_info.size < 1:
-                if self.tests is None:
-                    self.tests = {}
-                nfiles = len(folder_files)
-                nfiles_train = max(1, int(abs(group_info.size) * len(folder_files) - 0.5))
-                output.screen(group_info.name, ": Gathering ", nfiles, " fitting on ", nfiles_train)
-                self.tests[folder] = []
-                for i in range(nfiles - nfiles_train):
-                    self.tests[folder].append(self.files[folder].pop())
-
+            nfiles = len(folder_files)
+            if training_size < 1 or (training_size == 1 and size_type == float):
+                if training_size == 1:
+                    training_size = abs(training_size) * len(folder_files)
+                else:
+                    training_size = max(1, int(abs(training_size) * len(folder_files) - 0.5))
+                if bc_bool and testing_size == 0:
+                    testing_size = nfiles - training_size
+            if testing_size != 0 and (testing_size < 1 or (testing_size == 1 and testing_size_type == float)):
+                testing_size = max(1, int(abs(testing_size) * len(folder_files) - 0.5))
+            training_size = _float_to_int(training_size)
+            testing_size = _float_to_int(testing_size)
+            if nfiles-testing_size-training_size < 0:
+                raise ValueError("training size: {} + testing size: {} is greater than files in folder: {}".format(
+                    training_size, testing_size, nfiles))
+            output.screen(key, ": Detected ", nfiles, " fitting on ", training_size, " testing on ", testing_size)
+            if self.tests is None:
+                self.tests = {}
+            self.tests[folder] = []
+            for i in range(nfiles - training_size - testing_size):
+                self.files[folder].pop()
+            for i in range(testing_size):
+                self.tests[folder].append(self.files[folder].pop())
             # self.files[folder] = natsorted(self.files[folder])
 
     # TODO : Fix divvy up to distribute groups evenly and based on memory
@@ -103,13 +125,16 @@ class Scraper:
         group_list = []
         temp_list = []
         test_list = []
-        for i, folder in enumerate(self.files):
-            for file in self.files[folder]:
-                temp_list.append(file[0])
+        for i, folder in enumerate(self.configs):
+            for configuration in self.configs[folder]:
+                if isinstance(configuration, list):
+                    temp_list.append(configuration[0])
+                else:
+                    temp_list.append(configuration)
                 groups.append(folder)
 
-        self.files = temp_list
-        self.files = pt.split_by_node(self.files)
+        self.configs = temp_list
+        self.configs = pt.split_by_node(self.configs)
 
         if self.tests is not None:
             for i, folder in enumerate(self.tests):
@@ -117,7 +142,7 @@ class Scraper:
                     test_list.append(file[0])
                     group_list.append(folder)
             test_list = pt.split_by_node(test_list)
-            self.files += test_list
+            self.configs += test_list
 
         groups = pt.split_by_node(groups)
         group_list = pt.split_by_node(group_list)
@@ -127,17 +152,17 @@ class Scraper:
         for i, group in enumerate(group_set+group_test):
             group_counts[i] = groups.count(group)
 
-        pt.create_shared_array('files_per_group', len(self.files), dtype='i')
+        pt.create_shared_array('files_per_group', len(self.configs), dtype='i')
         pt.shared_arrays['files_per_group'].array = group_counts
 
         pt.shared_arrays['files_per_group'].testing = 0
         if self.tests is not None:
             pt.shared_arrays['files_per_group'].testing = len(test_list)
 
-        number_of_files_per_node = len(self.files)
+        number_of_files_per_node = len(self.configs)
         pt.create_shared_array('number_of_atoms', number_of_files_per_node, dtype='i')
         pt.slice_array('number_of_atoms')
-        self.files = pt.split_within_node(self.files)
+        self.configs = pt.split_within_node(self.configs)
 
     def scrape_configs(self):
         raise NotImplementedError("Call to virtual Scraper.scrape_configs method")
